==> modoboa-admin-1.0.1.tar.gz: modoboa-admin-1.0.1/modoboa_admin/tests/domain.py <==
"""Domain related test cases."""

from django.core.urlresolvers import reverse

from modoboa.core.models import User
from modoboa.lib import parameters
from modoboa.lib.tests import ModoTestCase

from .. import factories
from ..models import Domain, Alias


class DomainTestCase(ModoTestCase):

    """Test case for Domain."""

    def setUp(self):
        super(DomainTestCase, self).setUp()
        factories.populate_database()

    def test_create(self):
        """Test the creation of a domain."""
        values = {
            "name": "pouet.com", "quota": 100, "create_dom_admin": "no",
            "stepid": 'step2'
        }
        self.ajax_post(reverse("modoboa_admin:domain_add"), values)
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.name, "pouet.com")
        self.assertEqual(dom.quota, 100)
        self.assertEqual(dom.enabled, False)
        self.assertFalse(dom.admins)

    def test_create_with_template(self):
        """Test the creation of a domain with a template

        """
        values = {
            "name": "pouet.com", "quota": 100, "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "stepid": 'step2'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        da = User.objects.get(username="toto@pouet.com")
        self.assertIn(da, dom.admins)
        al = Alias.objects.get(address="postmaster", domain__name="pouet.com")
        self.assertIn(da.mailbox_set.all()[0], al.mboxes.all())
        self.assertTrue(da.can_access(al))

    def test_create_with_template_and_empty_quota(self):
        """Test the creation of a domain with a template and no quota"""
        values = {
            "name": "pouet.com", "quota": 0, "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "stepid": 'step2'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        da = User.objects.get(username="toto@pouet.com")
        self.assertIn(da, dom.admins)
        al = Alias.objects.get(address="postmaster", domain__name="pouet.com")
        self.assertIn(da.mailbox_set.all()[0], al.mboxes.all())
        self.assertTrue(da.can_access(al))

    def test_create_using_default_quota(self):
        parameters.save_admin('DEFAULT_DOMAIN_QUOTA', 50, app='modoboa_admin')
        values = {
            "name": "pouet.com", "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "stepid": 'step2'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.quota, 50)
        da = User.objects.get(username="toto@pouet.com")
        self.assertEqual(da.mailbox_set.all()[0].quota, 50)

    def test_modify(self):
        """Test the modification of a domain

        Rename 'test.com' domain to 'pouet.com'
        """
        values = {
            "name": "pouet.com", "quota": 100, "enabled": True
        }
        dom = Domain.objects.get(name="test.com")
        self.ajax_post(
            reverse("modoboa_admin:domain_change", args=[dom.id]),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.name, "pouet.com")
        self.assertTrue(dom.enabled)

    def test_delete(self):
        """Test the removal of a domain
        """
        dom = Domain.objects.get(name="test.com")
        self.ajax_post(
            reverse("modoboa_admin:domain_delete", args=[dom.id]),
            {}
        )
        with self.assertRaises(Domain.DoesNotExist):
            Domain.objects.get(pk=1)

==> modoboa-admin-1.1.1.tar.gz: modoboa-admin-1.1.1/modoboa_admin/tests/domain.py <==
"""Domain related test cases."""

from django.core.urlresolvers import reverse

from modoboa.core.models import User
from modoboa.lib import parameters
from modoboa.lib.tests import ModoTestCase

from .. import factories
from ..models import Domain, Alias


class DomainTestCase(ModoTestCase):

    """Test case for Domain."""

    def setUp(self):
        super(DomainTestCase, self).setUp()
        factories.populate_database()

    def test_create(self):
        """Test the creation of a domain."""
        values = {
            "name": "pouet.com", "quota": 100, "create_dom_admin": "no",
            "type": "domain", "stepid": "step3"
        }
        self.ajax_post(reverse("modoboa_admin:domain_add"), values)
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.name, "pouet.com")
        self.assertEqual(dom.quota, 100)
        self.assertEqual(dom.enabled, False)
        self.assertFalse(dom.admins)

    def test_create_with_template(self):
        """Test the creation of a domain with a template

        """
        values = {
            "name": "pouet.com", "quota": 100, "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "type": "domain", "stepid": 'step3'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        da = User.objects.get(username="toto@pouet.com")
        self.assertIn(da, dom.admins)
        al = Alias.objects.get(address="postmaster", domain__name="pouet.com")
        self.assertIn(da.mailbox_set.all()[0], al.mboxes.all())
        self.assertTrue(da.can_access(al))

    def test_create_with_template_and_empty_quota(self):
        """Test the creation of a domain with a template and no quota"""
        values = {
            "name": "pouet.com", "quota": 0, "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "type": "domain", "stepid": 'step3'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        da = User.objects.get(username="toto@pouet.com")
        self.assertIn(da, dom.admins)
        al = Alias.objects.get(address="postmaster", domain__name="pouet.com")
        self.assertIn(da.mailbox_set.all()[0], al.mboxes.all())
        self.assertTrue(da.can_access(al))

    def test_create_using_default_quota(self):
        parameters.save_admin('DEFAULT_DOMAIN_QUOTA', 50, app='modoboa_admin')
        values = {
            "name": "pouet.com", "create_dom_admin": "yes",
            "dom_admin_username": "toto", "create_aliases": "yes",
            "type": "domain", "stepid": 'step3'
        }
        self.ajax_post(
            reverse("modoboa_admin:domain_add"),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.quota, 50)
        da = User.objects.get(username="toto@pouet.com")
        self.assertEqual(da.mailbox_set.all()[0].quota, 50)

    def test_modify(self):
        """Test the modification of a domain

        Rename 'test.com' domain to 'pouet.com'
        """
        values = {
            "name": "pouet.com", "quota": 100, "type": "domain", "enabled": True
        }
        dom = Domain.objects.get(name="test.com")
        self.ajax_post(
            reverse("modoboa_admin:domain_change", args=[dom.id]),
            values
        )
        dom = Domain.objects.get(name="pouet.com")
        self.assertEqual(dom.name, "pouet.com")
        self.assertTrue(dom.enabled)

    def test_delete(self):
        """Test the removal of a domain
        """
        dom = Domain.objects.get(name="test.com")
        self.ajax_post(
            reverse("modoboa_admin:domain_delete", args=[dom.id]),
            {}
        )
        with self.assertRaises(Domain.DoesNotExist):
            Domain.objects.get(pk=1)
